# Changelog

All notable changes to this project will be documented in this file.

## [1.0.0] - 2022-08-15

### Bug Fixes

- Remove output files before running the tests
- Remove pèythonpath alteration in the test
- Typo

### Documentation

- Instructions for devs
- Version and docstring in top module init
- Instruction for dev with flit
- Explain empty parameters
- Better example in README

### Miscellaneous Tasks

- Isort | black
- Use pre-commits
- Basic git-cliff file for changelogs
- Add LICENSE
- Requirements for devs
- Add pytest test
- Remove unused main
- Remove depreciated code
- Use type hints
- Fix jinja2 sub dependency
- Better examples
- Ignore jinja2 types for mypy
- Add mypy as dev dependency
- Rename easy_grid -> easy_sge (WIP)
- Rename also folder

### Build

- Moving to pyproject (WIP)
- Set dependencies
- Remove requirements (now using pyproject.toml)
- Remove setup.py (now using pyproject.toml)

### Ci

- Simple CI to get started
- Install in root in CI
- Add stepsto publish to pypi

<!-- generated by git-cliff -->
